// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * BaseExistsConstraint.java
 * 
 * Author: Benjamin Keil
 * Modified:
 *    Made it extend AbstractEntityConstraint.
 *     -- Matt
 *    Ran it through JIndent, and added javadoc.
 *     -- Matt 26 Dec 1999
 *
 * Created 199911051504
 */
package org.datamanager.constraint;

import org.datamanager.constraint.EntityConstraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

import org.datamanager.tools.Debug;

/**
 * Filter out Entities that have a base which satisifies
 * a given EntityConstraint.
 * 
 * @author Benjamin Keil
 */
public class BaseExistsConstraint
    extends AbstractEntityConstraint
    {
    /**
     * The EntityConstraint used to find a valid base.
     */
    private EntityConstraint baseConstraint;

    /**
     * Create a new BaseExistsConstraint to match all
     * Entities that have a base matching the given
     * EntityConstraint.
     *
     * @param baseConstraint Constraint to use to match
     *                       bases.
     */
    public BaseExistsConstraint(EntityConstraint baseConstraint)
        {
        this.baseConstraint = baseConstraint;
        }

    /**
     * Check to see if the given Entity has a base
     * that satisfies the constraint given in the
     * constructor of this constraint.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the Entity has a base
     *         that satisfies the constraint given
     *         in the constructor of this constriant.
     */
    protected boolean describes(Entity defendant)
                         throws DataManagerException
        {
        Entity[] bases = defendant.getBases(EntityConstraint.NONE);
        boolean doesMatch = false;
        int index = 0;

        while ((index < bases.length) && (doesMatch != true))
            {
            doesMatch = baseConstraint.accepts(bases[index++]);
            }

        return doesMatch;
        }
    }