// For licensing, see: http://hydrogen.knownspace.org/license.html
///////////////////////////////////////////////////////////////////////////////
// 2002-10-07 cam
// Removed Debug.assert calls in constructor and replaced with
// IllegalArgumentExceptions.
///////////////////////////////////////////////////////////////////////////////

/**
 * EventClassIsConstraint.java
 *
 * Author: Matthew Farrellee
 */
package org.datamanager.constraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEventConstraint;

import org.datamanager.tools.Debug;

/**
 * Check to see if the type of a DataManagerEvent is
 * valid or not. Note: if the Class given to the
 * constructor is null this Constraint will always
 * return false.
 *
 * @author Matthew Farrellee
 */
public class EventTypeIsConstraint
    extends AbstractEventConstraint
    {
    /**
     * The target type.
     */
    private Class target;

    /**
     * Create a new EventTypeIsConstraint that will match
     * all DataManagerEvents that are of the given type,
     * this includes subtypes.
     *
     * @param target The type to target.
     * @throws IllegalArgumentException if target is null or
     *        target is not a DataManagerEvent class.
     */
    public EventTypeIsConstraint(Class target)
        {
        if (target == null)
            {
            throw new IllegalArgumentException("Given a null class.");
            }

        if (!target.isAssignableFrom(DataManagerEvent.class))
            {
            throw new IllegalArgumentException(
                    "Given class is not a DataManagerEvent.");
            }

        this.target = target;
        }

    /**
     * Check to see if the given DataManagerEvent is of
     * the type given in the constructor of this class.
     *
     * @param defendant A DataManagerEvent to check.
     *
     * @return Whether the given event is of the right type.
     */
    protected boolean describes(DataManagerEvent defendant)
                         throws DataManagerException
        {
        if (target == null)
            {
            return false;
            }
        else
            {
            return target.isAssignableFrom(defendant.getClass());
            }
        }
    }