// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * ValueClassIsConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;
import org.datamanager.kernel.EntityValue;

/**
 * Check to see if the class type of an Entity's value
 * is the same, or a subtype, of a specified class.
 *
 * @author Matthew Farrellee
 */
public class ValueClassIsConstraint
    extends AbstractEntityConstraint
    {
    /**
     * The class type to target.
     */
    private Class target;

    /**
     * Create a new ValueClassIsConstraint looking for the
     * given class type.
     *
     * @param target The type that is valid.
     */
    public ValueClassIsConstraint(Class target)
        {
        this.target = target;
        }

    /**
     * Check to see if the given Entity's value is of
     * the right type.
     *
     * @param defendant The Entity to check.
     *
     * @return Whether the given Entity is valid or not.
     */
    protected boolean describes(Entity defendant)
                         throws DataManagerException
        {
        EntityValue val;

        val = defendant.getValue();

        return val.getClass().isAssignableFrom(target);
        }
    }