// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.ValueEvent;

import org.datamanager.kernel.EntityValue;
import org.datamanager.kernel.EventGenerator;

/**
 * This event is only fired when
 * <code>Entity.setValue()</code> is invoked.
 *
 * @author Matthew Farrellee
 */
public class SetValueEvent
    extends DataManagerEventAdapter
    implements ValueEvent
    {
    /**
     * The old value of the <code>Entity</code>.
     */
    private EntityValue oldValue;
    /**
     * The new value of the <code>Entity</code>.
     */
    private EntityValue newValue;

    /**
     * The public constructor used to creare a
     * <code>SetValueEvent</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param oldValue The old value of the <code>Entity</code>.
     * @param newValue The new value of the <code>Entity</code>.
     */
    public SetValueEvent(EventGenerator source, EntityValue oldValue, 
                         EntityValue newValue)
        {
        super(source);
        this.oldValue = oldValue;
        this.newValue = newValue;
        }

    /**
     * Report the old value of the modified <code>Entity</code>.
     *
     * @return The old value of the <code>Entity</code> that this
     *         event came from.
     */
    public EntityValue getOldEntityValue()
        {
        return oldValue;
        }

    /**
     * Report the new value of the modified <code>Entity</code>.
     *
     * @return The new value of the <code>Entity</code> that
     *         this event came from.
     */
    public EntityValue getNewEntityValue()
        {
        return newValue;
        }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString()
        {
        return "SetValueEvent[[source: " + source + "]" + //     "[oldValue: " + oldValue + "]" +
               //     "[newValue: " + newValue + "]" +
        "[time: " + time + "]]";
        }
    }