// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.constraint.EventConstraint;

import org.datamanager.event.KernelEvent;

import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.EventHandler;

/**
 * This event is fired when
 * <code>EventGenerator.unsubscribed()</code> is invoked.
 *
 * @author Matthew Farrellee
 */
public class UnsubscribeEventGeneratorEvent
    extends DataManagerEventAdapter
    implements KernelEvent
    {
    /**
     * The <code>EventConstraint</code> that was unsubscribed.
     */
    private EventConstraint constraint;
    /**
     * The <code>EventHandler</code> that was unsubscribed.
     */
    private EventHandler handler;

    /**
     * This public constructor used to create a
     * <code>UnsubscribeEventGeneratorEvent</code> that does not contain
     * a <code>EventConstraint</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param handler The <code>EventHandler</code> that was
     *                unsubscribed.
     */
    public UnsubscribeEventGeneratorEvent(EventGenerator source, 
                                          EventHandler handler)
        {
        this(source, handler, null);
        }

    /**
     * This public constructor used to create a
     * <code>UnsubscribeEventGeneratorEvent</code> that does contain
     * a <code>EventConstraint</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param handler The <code>EventHandler</code> that was
     *                unsubscribed.
     * @param constraint The <code>EventConstraint</code> that was
     *                   unsubscribed.
     */
    public UnsubscribeEventGeneratorEvent(EventGenerator source, 
                                          EventHandler handler, 
                                          EventConstraint constraint)
        {
        super(source);
        this.handler = handler;
        this.constraint = constraint;
        }

    /**
     * Report the <code>EventHandler</code> that was unsubscribed.
     *
     * @return The <code>EventHandler</code> that was unsubscribed.
     */
    public EventHandler getEventHandler()
        {
        return handler;
        }

    /**
     * Report the <code>EventConstraint</code> that was unsubscribed.
     *
     * @return The <code>EventConstraint</code> that was unsubscribed.
     */
    public EventConstraint getConstraint()
        {
        return constraint;
        }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     * of this event.
     */
    public String toString()
        {
        return "UnsubscribeEventGeneratorEvent[[source: " + source + "]" + 
               "[eventHandler: " + handler + "]" + "[eventconstraint: " + 
               constraint + "]" + "[time: " + time + "]]";
        }
    }