// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * DoubleEntityValue.java
 * @author Benjamin Keil
 *
 * Created 199910252056
 */
package org.datamanager.passiveentityvalue;

import org.datamanager.kernel.EntityValue;

import org.datamanager.tools.Debug;

/**
 * DoubleEntityValue should give us all the functionality we need for working
 * with double values.  More explicit documentation given at NumberEntityValue
 *
 * @see NumberEntityValue#
 */
public class DoubleEntityValue
    extends NumberEntityValue
    {
    private double value;

    /**
     * The default value for DoubleEntityValue is 0.0
     */
    public DoubleEntityValue()
        {
        this(0.0);
        }

    /**
      * Create an DoubleEntityValue with the indicated value.
      */
    public DoubleEntityValue(double value)
        {
        this.value = value;
        }

    /**
      * Returns the hashCode of an equivalent Double object.
      */
    public int hashCode()
        {
        return (new Double(value)).hashCode();
        }

    ///////////////////////////////////////////////////////////////////////////
    //                                                                       //
    //                             Conversions                               //
    //                                                                       //
    ///////////////////////////////////////////////////////////////////////////
    // ----------------------     To Integer      -----------------------------
    public int getNearestInt()
        {
        return (int) Math.rint(value);
        }

    public int getFloor()
        {
        return (int) Math.floor(value);
        }

    public int getCeiling()
        {
        return (int) Math.ceil(value);
        }

    // ----------------------     To Double      ------------------------------
    public double getNearestDouble()
        {
        return value;
        }

    // ----------------------      To String     ------------------------------
    public String toString()
        {
        return "DoubleEntityValue[" + value + "]";
        }

    //////////////////////////////////////////////////////////////////////////
    // These methods allow Integer and DoubleEntityValues to share a lot of
    // code.
    //////////////////////////////////////////////////////////////////////////
    double getValue()
        {
        return value;
        }

    void setValue(double value)
        {
        this.value = value;
        }

    ///////////////////////////////////////////////////////////////////////////
    // These methods are added specifically for sO, but will probably be     //
    // necessary for whatever oodb we use.                                   //
    ///////////////////////////////////////////////////////////////////////////
    protected double DBGetValue()
        {
        return value;
        }

    protected void DBSetValue(double value)
        {
        this.value = value;
        }
    } // DoubleEntityValue
