// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.persistence.xml;

import java.util.Hashtable;
import java.util.Iterator;

/**
 * ObjectIDMap is a data structure to keep the mapping between ID and object.
 * It keep a key/value pair. The key is IDReference and the value is object.
 *
 * @author xi rao & Jason Lynn Baumgartner
 */
public class ObjectIDMap
    {
    private static final String OBJECT = "object";
    private Hashtable table;

    /**
     * Constructor: create an ObjectIDMap with a table to keep the object
     */
    public ObjectIDMap()
        {
        table = new Hashtable();
        }

    /**
     * check if the object already in the table
     * @param object Object instance
     * @return boolean true is object in the table
     */
    public boolean containsObject(Object object)
        {
        if (object == null)
            {
            return false;
            }

        return table.containsValue(object);
        }

    /**
     * check if the IDReference already in the table
     * @param idreference
     * @return boolean true is IDReference in the table
     */
    public boolean containsIDReference(String idreference)
        {
        return table.containsKey(idreference);
        }

    /**
     * add an instance into table, it will automatically generate a IDReference for that object
     * FixMe(10/10/2002): it is a urly algorithm to generate key(IDReference) for Object. We better
     * come with a better way.
     * @param object Object any instance
     */
    public void add(Object object)
        {
        String idvalue = OBJECT + String.valueOf(table.size());
        table.put(idvalue, object);
        }

    /**
     * add the instance/idreference paire into table
     * FixMe(10/10/2002): lack of protect for client, how about ID collision
     * @param idreference String represent object ID
     * @param object Object any instance
     */
    public void add(String idreference, Object object)
        {
        table.put(idreference, object);
        }

    /**
     * get the object by using idreference from table
     * @param idreference String represent object Id
     * @return Object an instance associate with Id in the table
     */
    public Object getObject(String idreference)
        {
        return table.get(idreference);
        }

    /**
     * get the IDReference from table by using object
     * @param object Object any instance
     * @return String a string associate with object in the table.
     */
    public String getIDReference(Object object)
        {
        String idreference = new String();
        Iterator iterate = table.keySet().iterator();

        while (iterate.hasNext())
            {
            String key = String.valueOf(iterate.next());
            Object value = table.get(key);

            if (value.equals(object))
                {
                idreference = key;
                }
            }

        return idreference;
        }

    /**
     * clear the table, remove all
     */
    public void clear()
        {
        table.clear();
        }
    }