// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.persistence.xml;

import java.io.*;

import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.w3c.dom.*;

import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * create a xml Docuemtn (www.w3c.com)
 *
 * @author xi rao & Jason Lynn Baumgartner
 */
public class XMLDocument
    {
    /**
     * create empty XML Document object
     * @return Document an w3c empty document
     */
    public static Document getXMLDocument()
        {
        return getDocumentBuilder().newDocument();
        }

    /**
     * create XML Docuemtment object from file
     * @param file File path/file name for keeping the xml on disk
     * @return Document XML document object form file
     */
    public static Document getXMLDocument(File file)
        {
        Document document = getXMLDocument();
        DocumentBuilder builder = getDocumentBuilder();

        if (builder instanceof DocumentBuilder)
            {
            try
                {
                FileInputStream fileInputStream = new FileInputStream(file);

                document = getXMLDocument(fileInputStream);
                }
            catch (IOException ioe)
                {
                ioe.printStackTrace();
                }
            }

        return document;
        }

    public static Document getXMLDocument(InputStream inputStream)
        {
        Document document = getXMLDocument();
        DocumentBuilder builder = getDocumentBuilder();

        if (builder instanceof DocumentBuilder)
            {
            try
                {
                InputSource inputSource = new InputSource(inputStream);

                //inputSource.setEncoding(XMLDataAccessObject.ENCODING);
                //System.out.println(inputSource.getEncoding());
                document = builder.parse(inputSource);
                }
            catch (SAXException se)
                {
                se.printStackTrace();
                }
            catch (IOException ioe)
                {
                ioe.printStackTrace();
                }
            }

        return document;
        }

    // create DocumentBuilder and set its property
    private static DocumentBuilder getDocumentBuilder()
        {
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        factory.setValidating(true);
        factory.setNamespaceAware(false);
        factory.setIgnoringComments(true);
        factory.setIgnoringElementContentWhitespace(true);
        factory.setCoalescing(true);
        factory.setExpandEntityReferences(true);

        DocumentBuilder builder = null;
        Document document = null;
        DefaultHandler handler = new DefaultHandler();

        try
            {
            builder = factory.newDocumentBuilder();
            builder.setEntityResolver(handler);
            builder.setErrorHandler(handler);
            }
        catch (ParserConfigurationException pce)
            {
            pce.printStackTrace();
            }

        return builder;
        }
    }