package org.datamanager.tools;

import java.util.LinkedList;

import org.datamanager.kernel.Simpleton.Information;

import org.w3c.dom.Node;

public class InformationParser
    {
    public static Information parseInformation(Node informationNode)
        {
        String className = null;
        String name = null;
        String shortDescription = null;
        String longDescription = null;
        String version = null;
        String[] authors = null;

        Node child = informationNode.getFirstChild();

        while (child != null)
            {
            if (child.getNodeType() == Node.ELEMENT_NODE)
                {
                if (child.getNodeName().equals("Class"))
                    {
                    className = parseInformationClass(child);
                    }
                else if (child.getNodeName().equals("Name"))
                    {
                    name = parseInformationName(child);
                    }
                else if (child.getNodeName().equals("ShortDescription"))
                    {
                    shortDescription = parseInformationShortDescription(child);
                    }
                else if (child.getNodeName().equals("LongDescription"))
                    {
                    longDescription = parseInformationLongDescription(child);
                    }
                else if (child.getNodeName().equals("Version"))
                    {
                    version = parseInformationVersion(child);
                    }
                else if (child.getNodeName().equals("AuthorList"))
                    {
                    authors = parseInformationAuthorList(child);
                    }
                else
                    {
                    // Error: Known tag.
                    }
                }

            child = child.getNextSibling();
            }

        if ((className == null) || (name == null) || 
                (shortDescription == null) || (longDescription == null) || 
                (version == null) || (authors == null))
            {
            return Information.NONE;
            }
        else
            {
            return new Information(className, name, shortDescription, 
                                   longDescription, version, authors);
            }
        }

    protected static String parseInformationClass(Node node)
        {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
        }

    protected static String parseInformationName(Node node)
        {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
        }

    protected static String parseInformationShortDescription(Node node)
        {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
        }

    protected static String parseInformationLongDescription(Node node)
        {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
        }

    protected static String parseInformationVersion(Node node)
        {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
        }

    protected static String[] parseInformationAuthorList(Node node)
        {
        LinkedList authors = new LinkedList();
        Node child = node.getFirstChild();

        while (child != null)
            {
            if (child.getNodeType() == Node.ELEMENT_NODE)
                {
                if (child.getNodeName().equals("Author"))
                    {
                    authors.add(parseInformationAuthorListAuthor(child));
                    }
                else
                    {
                    // Error: Known tag.
                    }
                }

            child = child.getNextSibling();
            }

        return (String[]) authors.toArray(new String[0]);
        }

    protected static String parseInformationAuthorListAuthor(Node node)
        {
        Node textNode = node.getFirstChild();

        return textNode.getNodeValue();
        }
    }