package org.datamanager.kernel;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import junit.framework.Assert;
/**
 * $Id: PoolTester.java,v 1.7 2002/10/14 07:06:40 alllee Exp $
 *
 *
 * Created: Thu Oct 10 00:21:35 2002
 *
 * @author <a href="mailto: alllee@cs.indiana.edu">Allen Lee</a>
 * @author <a href="mailto: rwgeorge@indiana.edu">Bob George</a>
 * @version $Revision: 1.7 $
 */

// nab - added tests for persist and restore
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.constraint.EntityConstraint;
import org.datamanager.constraint.EventConstraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.Entity;
import org.datamanager.kernel.Pool;
import org.datamanager.kernel.VerySimpleEntity;

import org.datamanager.passiveentityvalue.BooleanEntityValue;
import org.datamanager.passiveentityvalue.NullEntityValue;

public class PoolTester
    extends TestCase
    {
    private Pool pool;

    public PoolTester(String name)
        {
        super(name);
        }

    public static Test suite()
        {
        return new TestSuite(PoolTester.class);
        }

    protected void setUp()
        {
        pool = Pool.createDefaultPool();
        }

    protected void tearDown()
        {
        }

    public void testPoolNotNull()
        {
        assertTrue(pool != null);
        }

    public void testPoolIsPoo()
        {
        assertTrue(pool instanceof Pool);
        }

    public void testPoolIsSingleton()
        {
        assertTrue(pool == Pool.createDefaultPool());
        assertEquals(pool, Pool.createDefaultPool());
        }

    public void testAddEntity()
        {
        try
            {
            Entity testEntity = VerySimpleEntity.create("TestEntity");
            Entity attributeEntity = VerySimpleEntity.create("AttributeEntity");
            Entity booleanEntity = VerySimpleEntity.create("BooleanEntityValue");
            pool.add(testEntity);
            pool.add(attributeEntity);
            pool.add(booleanEntity);

            Entity[] allEntities = pool.search(EntityConstraint.NONE);
            assertTrue(allEntities.length >= 3);

            List entityList = Arrays.asList(allEntities);
            assertTrue(entityList.contains(testEntity));
            assertTrue(entityList.contains(attributeEntity));
            assertTrue(entityList.contains(booleanEntity));

            //EventConstraint constraint = new AbstractEventConstraint()
            }
        catch (DataManagerException exception)
            {
            exception.printStackTrace();
            }
        }

    public void testPersist()
        {
        try
            {
            Entity testEntity = VerySimpleEntity.create("TestEntity");
            Entity attributeEntity = VerySimpleEntity.create("AttributeEntity");
            Entity booleanEntity = VerySimpleEntity.create("BooleanEntityValue");
            pool.add(testEntity);
            pool.add(attributeEntity);
            pool.add(booleanEntity);
            pool.persist(Pool.PERSISTENCE_DEFAULT_FILE);
            assertTrue(Pool.PERSISTENCE_DEFAULT_FILE.exists());

            Pool restoredPool = Pool.getDefaultPool();
            assertTrue(restoredPool == pool);
            assertEquals(restoredPool, pool);
            }
        catch (Exception e)
            {
            e.printStackTrace();
            fail("Persistence test on Pool failed");
            }
        }
    } // PoolTester
